@@ -27,7 +27,7 @@ def test_request_token():
 
     access_token = jwt.encode(access_token_layout,
                               'secret', algorithm='HS256',
-                              headers={'kid': '230498151c214b788dd97f22b85410a5'}).decode('utf-8')
+                              headers={'kid': '230498151c214b788dd97f22b85410a5'})
     response = {
         "accessToken": access_token,
     }
